@@ -14,13 +14,9 @@
 
 from mistral.actions import std_actions
 from mistral import exceptions
-from oslo_log import log as logging
 from oslo_utils import uuidutils
 
 
-LOG = logging.getLogger('mistral.actions.solum')
-
-
 class CreateImageAction(std_actions.HTTPAction):
     def __init__(self, build_service_url, action_context,
                  source_uri, name, base_image_id,
