@@ -12,7 +12,8 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-from solum.openstack.common import log as logging
+from oslo_log import log as logging
+
 import solum.uploaders.common
 
 LOG = logging.getLogger(__name__)
